Welcome to the s1ard documentation!
===================================

s1ard is a prototype processor to create the Sentinel-1 Analysis Ready Data (ARD) products
Normalised Radar Backscatter (S1-NRB) and Ocean Radar Backscatter (S1-ORB).
Further information about these products can be found
`here <https://sentiwiki.copernicus.eu/web/s1-products#S1Products-Sentinel-1ARDNormalisedRadarBackscatter(NRB)ProductS1-Products-Sentinel-1-ARD-Normalised-Radar-Backscatter>`_.

.. toctree::
    :maxdepth: 2

    general/index.rst
    api/index.rst
    examples/index.rst
    about/index.rst
    tocs.rst
